@@ -34,9 +34,9 @@ SEXP netfastpinter2(   SEXP   efac2,   SEXP edims2,
 
 
 double pystep(int nc,        int  *index,  int  *index2,   double *wt,
-	      double *data,  Sint *fac,    Sint *dims,     double **cuts,
+	      double *data,  int *fac,    int *dims,     double **cuts,
 	      double step,   int  edge);
 
 double pystep2(int nc,        int  *index,  int  *index2,   double *wt,
-	      double *data,  Sint *fac,    Sint *dims,     double **cuts,
+	      double *data,  int *fac,    int *dims,     double **cuts,
 	      double step,   int  edge);
